factorize_simplicial_numeric_qr_scratch

Function factorize_simplicial_numeric_qr_scratch 

pub fn factorize_simplicial_numeric_qr_scratch<I: Index, T: ComplexField>(
    symbolic: &SymbolicSimplicialQr<I>,
) -> StackReq
computes the size and alignment of the workspace required to compute the numerical $QR$ factorization of the matrix whose structure was used to produce the symbolic structure