SimplicialQrRef

Struct SimplicialQrRef 

pub struct SimplicialQrRef<'a, I, T> { /* private fields */ }
$QR$ factors containing both the symbolic and numeric representations

Implementations

Source

impl<'a, I: Index, T> SimplicialQrRef<'a, I, T>

pub fn new( symbolic: &'a SymbolicSimplicialQr<I>, r: SparseColMatRef<'a, I, T>, householder: SparseColMatRef<'a, I, T>, tau_val: &'a [T], ) -> Self

creates $QR$ factors from their components

pub fn symbolic(&self) -> &SymbolicSimplicialQr<I>

returns the symbolic structure of the $QR$ factorization.

pub fn R_val(self) -> &'a [T]

returns the numerical values of the factor $R$ of the $QR$ factorization

pub fn R(self) -> SparseColMatRef<'a, I, T>

returns the factor $R$

pub fn householder(self) -> SparseColMatRef<'a, I, T>

returns the householder coefficients $H$ in the columns of a sparse matrix

pub fn householder_val(self) -> &'a [T]

returns the numerical values of the householder factors of the $QR$ factorization.

pub fn tau_val(self) -> &'a [T]

returns the numerical values of the $t$ factors of the $QR$ factorization.

pub fn apply_qt_in_place_with_conj( &self, conj_qr: Conj, rhs: MatMut<'_, T>, par: Par, work: MatMut<'_, T>, )
where T: ComplexField,

Applies $Q^{\top}$ to the input matrix rhs, implicitly conjugating the $Q$ matrix if needed

work is a temporary workspace with the same dimensions as rhs.

pub fn solve_in_place_with_conj( &self, conj_qr: Conj, rhs: MatMut<'_, T>, par: Par, work: MatMut<'_, T>, )
where T: ComplexField,

solves the equation $A x = \text{rhs}$ in the sense of least squares, implicitly conjugating $A$ if needed

work is a temporary workspace with the same dimensions as rhs.