pub struct SimplicialQrRef<'a, I, T> { /* private fields */ }Expand description
$QR$ factors containing both the symbolic and numeric representations
Implementations
Sourceimpl<'a, I: Index, T> SimplicialQrRef<'a, I, T>
impl<'a, I: Index, T> SimplicialQrRef<'a, I, T>
Sourcepub fn new(
symbolic: &'a SymbolicSimplicialQr<I>,
r: SparseColMatRef<'a, I, T>,
householder: SparseColMatRef<'a, I, T>,
tau_val: &'a [T],
) -> Self
pub fn new( symbolic: &'a SymbolicSimplicialQr<I>, r: SparseColMatRef<'a, I, T>, householder: SparseColMatRef<'a, I, T>, tau_val: &'a [T], ) -> Self
creates $QR$ factors from their components
Sourcepub fn symbolic(&self) -> &SymbolicSimplicialQr<I>
pub fn symbolic(&self) -> &SymbolicSimplicialQr<I>
returns the symbolic structure of the $QR$ factorization.
Sourcepub fn R_val(self) -> &'a [T]
pub fn R_val(self) -> &'a [T]
returns the numerical values of the factor $R$ of the $QR$ factorization
Sourcepub fn R(self) -> SparseColMatRef<'a, I, T>
pub fn R(self) -> SparseColMatRef<'a, I, T>
returns the factor $R$
Sourcepub fn householder(self) -> SparseColMatRef<'a, I, T>
pub fn householder(self) -> SparseColMatRef<'a, I, T>
returns the householder coefficients $H$ in the columns of a sparse matrix
Sourcepub fn householder_val(self) -> &'a [T]
pub fn householder_val(self) -> &'a [T]
returns the numerical values of the householder factors of the $QR$ factorization.
Sourcepub fn tau_val(self) -> &'a [T]
pub fn tau_val(self) -> &'a [T]
returns the numerical values of the $t$ factors of the $QR$ factorization.
Sourcepub fn apply_qt_in_place_with_conj(
&self,
conj_qr: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
)where
T: ComplexField,
pub fn apply_qt_in_place_with_conj(
&self,
conj_qr: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
)where
T: ComplexField,
Applies $Q^{\top}$ to the input matrix rhs, implicitly conjugating the $Q$
matrix if needed
work is a temporary workspace with the same dimensions as rhs.
Sourcepub fn solve_in_place_with_conj(
&self,
conj_qr: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
)where
T: ComplexField,
pub fn solve_in_place_with_conj(
&self,
conj_qr: Conj,
rhs: MatMut<'_, T>,
par: Par,
work: MatMut<'_, T>,
)where
T: ComplexField,
solves the equation $A x = \text{rhs}$ in the sense of least squares, implicitly conjugating $A$ if needed
work is a temporary workspace with the same dimensions as rhs.